# 简介

tep是Try Easy Pytest的首字母缩写，帮你轻松上手pytest。

框架特点：
- 基于pytest封装，成熟、稳定且扩展性强。
- 框架完全由Python构建，没有混杂其他语言。
- 原生Python语法，学习Python，零成本使用框架。
- HAR包转换pytest用例。
- 函数v()支持${}占位符语法，便捷管理接口数据。

# 安装

支持Python3.8以上版本

创建虚拟环境：`python -m venv .venv`

激活虚拟环境，Windows用户：`activate.bat` Mac用户：`source .venv/bin/activate`

安装tep：`pip install tep`

验证安装成功：`tep -V`


``` text
Current Version: V3.0.1

████████ ███████ ██████  
   ██    ██      ██   ██ 
   ██    █████   ██████  
   ██    ██      ██      
   ██    ███████ ██      
```

# 更多介绍

[原创接口测试框架tep](https://dongfanger.github.io/chapters/%E5%8E%9F%E5%88%9B%E6%8E%A5%E5%8F%A3%E6%B5%8B%E8%AF%95%E6%A1%86%E6%9E%B6tep.html)

# 重要版本说明
- V3.0.0 纯粹Python接口测试框架
- V2.0.0 关键字驱动框架
- V1.0.0 tep小工具完整教程
- V0.2.3 tep小工具首次开源